@@ -17,11 +17,11 @@ memoize('bernoulli');
 sub bernoulli {
     my ($n) = @_;
 
-    return 1 / 2 if $n == 1;
-    return 0     if $n % 2;
-    return 1     if $n == 0;
+    return 1/2 if $n == '1';
+    return 0   if $n  % '2';
+    return 1   if $n == '0';
 
-    my $bern = 1 / 2 - 1 / ($n + 1);
+    my $bern = 1/2 - 1/($n + 1);
     for (my $k = '2' ; $k < $n ; $k += '2') {
         $bern -= bernoulli($k) * binomial($n, $k) / ($n - $k + 1);
     }
